pub struct DeviceGetNodeGraphResponse {
pub nodes: Vec<Node>,
pub edges: Vec<Edge>,
}Fields
nodes: Vec<Node>edges: Vec<Edge>Trait Implementations
Sourceimpl Clone for DeviceGetNodeGraphResponse
impl Clone for DeviceGetNodeGraphResponse
Sourcefn clone(&self) -> DeviceGetNodeGraphResponse
fn clone(&self) -> DeviceGetNodeGraphResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetNodeGraphResponse
impl Debug for DeviceGetNodeGraphResponse
Sourceimpl<'a, ___E> Encode<DeviceGetNodeGraphResponse<'static>, ___E> for &'a DeviceGetNodeGraphResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceGetNodeGraphResponse<'static>, ___E> for &'a DeviceGetNodeGraphResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetNodeGraphResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetNodeGraphResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetNodeGraphResponse<'static>, ___E> for DeviceGetNodeGraphResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceGetNodeGraphResponse<'static>, ___E> for DeviceGetNodeGraphResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetNodeGraphResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetNodeGraphResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetNodeGraphResponse<'static>>, ___E> for &'a DeviceGetNodeGraphResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetNodeGraphResponse: Encode<DeviceGetNodeGraphResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetNodeGraphResponse<'static>>, ___E> for &'a DeviceGetNodeGraphResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetNodeGraphResponse: Encode<DeviceGetNodeGraphResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetNodeGraphResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetNodeGraphResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetNodeGraphResponse<'static>>, ___E> for DeviceGetNodeGraphResponsewhere
___E: Encoder + ?Sized,
DeviceGetNodeGraphResponse: Encode<DeviceGetNodeGraphResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetNodeGraphResponse<'static>>, ___E> for DeviceGetNodeGraphResponsewhere
___E: Encoder + ?Sized,
DeviceGetNodeGraphResponse: Encode<DeviceGetNodeGraphResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetNodeGraphResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetNodeGraphResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceGetNodeGraphResponse<'de>> for DeviceGetNodeGraphResponse
impl<'de> FromWire<DeviceGetNodeGraphResponse<'de>> for DeviceGetNodeGraphResponse
Sourcefn from_wire(wire: DeviceGetNodeGraphResponse<'de>) -> Self
fn from_wire(wire: DeviceGetNodeGraphResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceGetNodeGraphResponse<'de>> for DeviceGetNodeGraphResponse
impl<'de> FromWireRef<DeviceGetNodeGraphResponse<'de>> for DeviceGetNodeGraphResponse
Sourcefn from_wire_ref(wire: &DeviceGetNodeGraphResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceGetNodeGraphResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetNodeGraphResponse
impl Hash for DeviceGetNodeGraphResponse
Sourceimpl Ord for DeviceGetNodeGraphResponse
impl Ord for DeviceGetNodeGraphResponse
Sourcefn cmp(&self, other: &DeviceGetNodeGraphResponse) -> Ordering
fn cmp(&self, other: &DeviceGetNodeGraphResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for DeviceGetNodeGraphResponse
impl PartialOrd for DeviceGetNodeGraphResponse
impl Eq for DeviceGetNodeGraphResponse
impl StructuralPartialEq for DeviceGetNodeGraphResponse