pub struct DeviceGetPathEndpointsResponse {
pub paths: Vec<PathEndpoints>,
}Fields
paths: Vec<PathEndpoints>Trait Implementations
Sourceimpl Clone for DeviceGetPathEndpointsResponse
impl Clone for DeviceGetPathEndpointsResponse
Sourcefn clone(&self) -> DeviceGetPathEndpointsResponse
fn clone(&self) -> DeviceGetPathEndpointsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceGetPathEndpointsResponse<'static>, ___E> for &'a DeviceGetPathEndpointsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceGetPathEndpointsResponse<'static>, ___E> for &'a DeviceGetPathEndpointsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPathEndpointsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPathEndpointsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetPathEndpointsResponse<'static>, ___E> for DeviceGetPathEndpointsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceGetPathEndpointsResponse<'static>, ___E> for DeviceGetPathEndpointsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPathEndpointsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPathEndpointsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetPathEndpointsResponse<'static>>, ___E> for &'a DeviceGetPathEndpointsResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetPathEndpointsResponse: Encode<DeviceGetPathEndpointsResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetPathEndpointsResponse<'static>>, ___E> for &'a DeviceGetPathEndpointsResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetPathEndpointsResponse: Encode<DeviceGetPathEndpointsResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetPathEndpointsResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetPathEndpointsResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetPathEndpointsResponse<'static>>, ___E> for DeviceGetPathEndpointsResponsewhere
___E: Encoder + ?Sized,
DeviceGetPathEndpointsResponse: Encode<DeviceGetPathEndpointsResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetPathEndpointsResponse<'static>>, ___E> for DeviceGetPathEndpointsResponsewhere
___E: Encoder + ?Sized,
DeviceGetPathEndpointsResponse: Encode<DeviceGetPathEndpointsResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetPathEndpointsResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetPathEndpointsResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceGetPathEndpointsResponse<'de>> for DeviceGetPathEndpointsResponse
impl<'de> FromWire<DeviceGetPathEndpointsResponse<'de>> for DeviceGetPathEndpointsResponse
Sourcefn from_wire(wire: DeviceGetPathEndpointsResponse<'de>) -> Self
fn from_wire(wire: DeviceGetPathEndpointsResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceGetPathEndpointsResponse<'de>> for DeviceGetPathEndpointsResponse
impl<'de> FromWireRef<DeviceGetPathEndpointsResponse<'de>> for DeviceGetPathEndpointsResponse
Sourcefn from_wire_ref(wire: &DeviceGetPathEndpointsResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceGetPathEndpointsResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for DeviceGetPathEndpointsResponse
impl Ord for DeviceGetPathEndpointsResponse
Sourcefn cmp(&self, other: &DeviceGetPathEndpointsResponse) -> Ordering
fn cmp(&self, other: &DeviceGetPathEndpointsResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetPathEndpointsResponse
impl PartialEq for DeviceGetPathEndpointsResponse
Sourcefn eq(&self, other: &DeviceGetPathEndpointsResponse) -> bool
fn eq(&self, other: &DeviceGetPathEndpointsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetPathEndpointsResponse
impl PartialOrd for DeviceGetPathEndpointsResponse
impl Eq for DeviceGetPathEndpointsResponse
impl StructuralPartialEq for DeviceGetPathEndpointsResponse