pub struct DeviceSetNodesBandwidthResponse {
pub aggregated_bandwidth: Vec<AggregatedBandwidth>,
}Fields
aggregated_bandwidth: Vec<AggregatedBandwidth>Trait Implementations
Sourceimpl Clone for DeviceSetNodesBandwidthResponse
impl Clone for DeviceSetNodesBandwidthResponse
Sourcefn clone(&self) -> DeviceSetNodesBandwidthResponse
fn clone(&self) -> DeviceSetNodesBandwidthResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceSetNodesBandwidthResponse<'static>, ___E> for &'a DeviceSetNodesBandwidthResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceSetNodesBandwidthResponse<'static>, ___E> for &'a DeviceSetNodesBandwidthResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceSetNodesBandwidthResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceSetNodesBandwidthResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceSetNodesBandwidthResponse<'static>, ___E> for DeviceSetNodesBandwidthResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceSetNodesBandwidthResponse<'static>, ___E> for DeviceSetNodesBandwidthResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceSetNodesBandwidthResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceSetNodesBandwidthResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceSetNodesBandwidthResponse<'static>>, ___E> for &'a DeviceSetNodesBandwidthResponsewhere
___E: Encoder + ?Sized,
&'a DeviceSetNodesBandwidthResponse: Encode<DeviceSetNodesBandwidthResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceSetNodesBandwidthResponse<'static>>, ___E> for &'a DeviceSetNodesBandwidthResponsewhere
___E: Encoder + ?Sized,
&'a DeviceSetNodesBandwidthResponse: Encode<DeviceSetNodesBandwidthResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceSetNodesBandwidthResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceSetNodesBandwidthResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceSetNodesBandwidthResponse<'static>>, ___E> for DeviceSetNodesBandwidthResponsewhere
___E: Encoder + ?Sized,
DeviceSetNodesBandwidthResponse: Encode<DeviceSetNodesBandwidthResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceSetNodesBandwidthResponse<'static>>, ___E> for DeviceSetNodesBandwidthResponsewhere
___E: Encoder + ?Sized,
DeviceSetNodesBandwidthResponse: Encode<DeviceSetNodesBandwidthResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceSetNodesBandwidthResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceSetNodesBandwidthResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceSetNodesBandwidthResponse<'de>> for DeviceSetNodesBandwidthResponse
impl<'de> FromWire<DeviceSetNodesBandwidthResponse<'de>> for DeviceSetNodesBandwidthResponse
Sourcefn from_wire(wire: DeviceSetNodesBandwidthResponse<'de>) -> Self
fn from_wire(wire: DeviceSetNodesBandwidthResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceSetNodesBandwidthResponse<'de>> for DeviceSetNodesBandwidthResponse
impl<'de> FromWireRef<DeviceSetNodesBandwidthResponse<'de>> for DeviceSetNodesBandwidthResponse
Sourcefn from_wire_ref(wire: &DeviceSetNodesBandwidthResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceSetNodesBandwidthResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for DeviceSetNodesBandwidthResponse
impl Ord for DeviceSetNodesBandwidthResponse
Sourcefn cmp(&self, other: &DeviceSetNodesBandwidthResponse) -> Ordering
fn cmp(&self, other: &DeviceSetNodesBandwidthResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceSetNodesBandwidthResponse
impl PartialEq for DeviceSetNodesBandwidthResponse
Sourcefn eq(&self, other: &DeviceSetNodesBandwidthResponse) -> bool
fn eq(&self, other: &DeviceSetNodesBandwidthResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceSetNodesBandwidthResponse
impl PartialOrd for DeviceSetNodesBandwidthResponse
impl Eq for DeviceSetNodesBandwidthResponse
impl StructuralPartialEq for DeviceSetNodesBandwidthResponse